@@ -33,6 +33,10 @@
 #include "ode_solver.h"
 #include "ode.h"
 #include "code.h"
+#include "random.h"
+#include "randist.h"
+#include "pdf.h"
+#include "cdf.h"
 
 static const struct luaL_Reg gsl_methods_dummy[] = {{NULL, NULL}};
 
@@ -53,6 +57,10 @@ luaopen_gsl (lua_State *L)
   integ_register (L);
   ode_solver_register (L);
   ode_register (L);
+  random_register (L);
+  randist_register (L);
+  pdf_register (L);
+  cdf_register (L);
 
 #ifdef LNUM_COMPLEX
   lua_pushboolean (L, 1);
